class TransportLayerProtocol:
    """
    Transport Layer Protocols

    IDs match IANA numbering https://en.wikipedia.org/wiki/List_of_IP_protocol_numbers
    """

    TCP = 6
    UDP = 17
